#include <cstring>
#include <string>

namespace SciChart {
enum class SCRTLicenseType {
  /// Invalid but informs the user a trial is being requested.
  LICENSE_TYPE_NO_LICENSE = 0,
  /// Trial - Valid but with trial notices
  LICENSE_TYPE_TRIAL = 0x02,
  /// Community - Watermark but no expiry
  LICENSE_TYPE_COMMUNITY = 0x03,
  /// Full - Valid
  LICENSE_TYPE_FULL = 0x20,
  /// Full expired - For Non-perpetual (web)
  LICENSE_TYPE_FULL_EXPIRED = 0x04,
  /// Trial expired - Invalid
  LICENSE_TYPE_TRIAL_EXPIRED = 0x40,
  /// Subscription expired - build is after expiry date
  LICENSE_TYPE_SUBSCRIPTION_EXPIRED = 0x80,
  /// Invalid developer license - Invalid machine specific license
  LICENSE_TYPE_INVALID_DEVELOPER_LICENSE = 0x0F,
  /// License that requires server validation
  LICENSE_TYPE_REQUIRES_VALIDATION = 0x2F,
  /// Invalid license - Invalid runtime license
  LICENSE_TYPE_INVALID_LICENSE = 0xFF
};

namespace LicenseServer {

void ResetRuntimeLicense();

bool SetAssemblyName(const std::string &_assemblyName);

/// Sets the Runtime License ( narrow string version ).
/// Returns true passed license key is valid; otherwise false.
bool SetRuntimeLicenseKey(const std::string &_strKey);

/// Gets a type of the Runtime License.
SCRTLicenseType GetLicenseType();

/// Determines whether the Runtime License is valid.
bool CheckLicenseValid();

/// Gets the OrderId of the current license
std::string GetOrderId();

/// Gets the reason for the license failure
std::string GetLicenseErrors();

/// Decode and check challenge.  Generate response with encrypted expiry
std::string ValidateChallenge(const std::string &_challenge);

/// Dumps the information of the Runtime License to returned string.
std::string Dump();

} // namespace LicenseServer
} // namespace SciChart

#ifdef __cplusplus
extern "C" {
#endif
bool SciChartSCS_SetRuntimeLicenseKey(char* _strKey);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C" {
#endif
char *SciChartSCS_GetLicenseErrors();
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C" {
#endif
char *SciChartSCS_ValidateChallenge(char* _challenge);
#ifdef __cplusplus
}
#endif
